@@ -1,5 +1,5 @@
 #ifndef lint
-static char *RCSid() { return RCSid("$Id: command.c,v 1.230.2.11 2013/07/22 22:19:10 sfeam Exp $"); }
+static char *RCSid() { return RCSid("$Id: command.c,v 1.230.2.14 2014/01/29 19:08:57 sfeam Exp $"); }
 #endif
 
 /* GNUPLOT - command.c */
@@ -1641,12 +1641,15 @@ refresh_request()
     CHECK_REVERSE(SECOND_Y_AXIS);
 #undef CHECK_REVERSE
 
-    if (refresh_ok == 2)
+    if (refresh_ok == 2) {
 	do_plot(first_plot, refresh_nplots);
-    else if (refresh_ok == 3)
+	update_gpval_variables(1);
+    } else if (refresh_ok == 3) {
 	do_3dplot(first_3dplot, refresh_nplots, 0);
-    else
+	update_gpval_variables(1);
+    } else {
 	int_error(NO_CARET, "Internal error - refresh of unknown plot type");
+    }
 
 }
 
@@ -1956,9 +1959,6 @@ title 'R,G,B profiles of the current color palette';";
     free(replot_line);
     replot_line = save_replot_line;
     is_3d_plot = save_is_3d_plot;
-
-    /* further, gp_input_line[] and token[] now destroyed! */
-    c_token = num_tokens = 0;
 }
 
 
@@ -3043,8 +3043,8 @@ expand_1level_macros()
 		    while (isalnum(*c) || (*c=='_')) c++;
 		    temp_char = *c; *c = '\0';
 		    /* Look up the key and restore the original following char */
-		    udv = add_udv_by_name(m);
-		    if (udv && udv->udv_value.type == STRING) {
+		    udv = get_udv_by_name(m);
+		    if (udv && !udv->udv_undef && udv->udv_value.type == STRING) {
 			nfound++;
 			m = udv->udv_value.v.string_val;
 			FPRINTF((stderr,"Replacing @%s with \"%s\"\n",udv->udv_name,m));
