@@ -1,5 +1,5 @@
 #ifndef lint
-static char *RCSid() { return RCSid("$Id: mouse.c,v 1.133.2.3 2012/10/27 02:24:37 sfeam Exp $"); }
+static char *RCSid() { return RCSid("$Id: mouse.c,v 1.133.2.5 2013/11/10 18:44:22 sfeam Exp $"); }
 #endif
 
 /* GNUPLOT - mouse.c */
@@ -1831,9 +1831,11 @@ event_buttonrelease(struct gp_event_t *ge)
 
     /* In 2D mouse button 1 is available for "bind" commands */
     if (!is_3d_plot && (b == 1)) {
+	int save = ge->par1;
 	ge->par1 = GP_Button1;
 	ge->par2 = 0;
 	event_keypress(ge, TRUE);
+	ge->par1 = save;	/* needed for "pause mouse" */
     }
 
 #ifdef _Windows
@@ -1986,7 +1988,7 @@ event_reset(struct gp_event_t *ge)
     modifier_mask = 0;
     button = 0;
     builtin_cancel_zoom(ge);
-    if (term && term->set_cursor) {
+    if (term && term_initialised && term->set_cursor) {
 	term->set_cursor(0, 0, 0);
 	if (mouse_setting.annotate_zoom_box && term->put_tmptext) {
 	    term->put_tmptext(1, "");
