@@ -611,14 +611,17 @@ void QtGnuplotScene::mouseReleaseEvent(QGraphicsSceneMouseEvent* event)
 
 	// EAM FIXME - If the press/release events get out of order or if we see
 	// a very fast double-click then the following call causes the program
-	// to error out during event processing.  Also note that I can't find
-	// where the timers are initialized on entry - maybe a problem there?
-	// Finally, why do we need or want a timer at all?
-	int time = m_watches[button].elapsed();
-	if (time > 300) // purely empical work-around
-	if (m_eventHandler->postTermEvent(GE_buttonrelease, int(event->scenePos().x()),
-	    int(event->scenePos().y()), button, time, 0))
+	// to error out during event processing.  Unfortunately I have not been
+	// able to reliably filter out these spurious events by setting a timing
+	// window.
+	qint64 time = 0;
+	if (m_watches[button].isValid())
+		time = m_watches[button].elapsed();
+	if (time > 300) {
+		m_eventHandler->postTermEvent(GE_buttonrelease, int(event->scenePos().x()),
+				int(event->scenePos().y()), button, time, 0);
 		m_watches[button].start();
+	}
 
 	/* Check for click in one of the keysample boxes */
 	int i = m_key_boxes.count();
