@@ -1,5 +1,5 @@
 /*
- * $Id: winmain.c,v 1.52.2.3 2013/06/08 11:52:33 markisch Exp $
+ * $Id: winmain.c,v 1.52.2.5 2014/01/11 16:22:14 markisch Exp $
  */
 
 /* GNUPLOT - win/winmain.c */
@@ -432,18 +432,22 @@ int PASCAL WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance,
 int main(int argc, char **argv)
 #endif
 {
-        LPSTR tail;
+	LPSTR tail;
 	int i;
 
 #ifdef WGP_CONSOLE
-# define _argv argv
-# define _argc argc
-        HINSTANCE hInstance = GetModuleHandle(NULL), hPrevInstance = NULL;
-#else
-#if defined(__MSC__) || defined(__WATCOMC__) || defined(__MINGW32__)
-#  define _argv __argv
-#  define _argc __argc
+	HINSTANCE hInstance = GetModuleHandle(NULL), hPrevInstance = NULL;
 #endif
+
+
+#ifndef WGP_CONSOLE
+# if defined( __MINGW32__) && !defined(_W64)
+#  define argc _argc
+#  define argv _argv
+# else /* MSVC, WATCOM, MINGW-W64 */
+#  define argc __argc
+#  define argv __argv
+# endif
 #endif /* WGP_CONSOLE */
 
         szModuleName = (LPSTR)malloc(MAXSTR+1);
@@ -561,10 +565,10 @@ int main(int argc, char **argv)
 	 * command line arguments are file names or an explicit in-line "-e command".
 	 * (This is a copy of a code snippet from plot.c)
 	 */
-	for (i = 1; i < _argc; i++) {
-		if (!stricmp(_argv[i], "/noend"))
+	for (i = 1; i < argc; i++) {
+		if (!stricmp(argv[i], "/noend"))
 			continue;
-		if ((_argv[i][0] != '-') || (_argv[i][1] == 'e')) {
+		if ((argv[i][0] != '-') || (argv[i][1] == 'e')) {
 			interactive = FALSE;
 			break;
 		}
@@ -596,17 +600,17 @@ int main(int argc, char **argv)
 #endif
 #endif
 
-        atexit(WinExit);
+	atexit(WinExit);
 
-        if (!isatty(fileno(stdin)))
-            setmode(fileno(stdin), O_BINARY);
+	if (!isatty(fileno(stdin)))
+		setmode(fileno(stdin), O_BINARY);
 
-        gnu_main(_argc, _argv);
+	gnu_main(argc, argv);
 
-        /* First chance to close help system for console gnuplot,
-        second for wgnuplot */
-        WinCloseHelp();
-        return 0;
+	/* First chance to close help system for console gnuplot,
+	second for wgnuplot */
+	WinCloseHelp();
+	return 0;
 }
 
 
@@ -881,12 +885,16 @@ int ConsoleGetch()
                 DWORD recRead;
 
                 ReadConsoleInput(h, &rec, 1, &recRead);
+				/* FIXME: We should handle rec.Event.KeyEvent.wRepeatCount > 1, too. */
                 if (recRead == 1 && rec.EventType == KEY_EVENT && rec.Event.KeyEvent.bKeyDown &&
                         (rec.Event.KeyEvent.wVirtualKeyCode < VK_SHIFT ||
                          rec.Event.KeyEvent.wVirtualKeyCode > VK_MENU))
                 {
                     if (rec.Event.KeyEvent.uChar.AsciiChar)
-                        return rec.Event.KeyEvent.uChar.AsciiChar;
+						if ((rec.Event.KeyEvent.dwControlKeyState == SHIFT_PRESSED) && (rec.Event.KeyEvent.wVirtualKeyCode == VK_TAB))
+							return 034; /* remap Shift-Tab */
+						else
+							return rec.Event.KeyEvent.uChar.AsciiChar;
                     else
                         switch (rec.Event.KeyEvent.wVirtualKeyCode)
                         {
@@ -1011,7 +1019,7 @@ win_lower_terminal_group(void)
 }
 
 
-/* return the number of graph windows (win terminal)*/
+/* returns true if there are any graph windows open (win terminal) */
 TBOOLEAN
 WinWindowOpened(void)
 {
@@ -1061,11 +1069,11 @@ void
 WinRaiseConsole(void)
 {
 	HWND console = NULL;
-# ifndef WGP_CONSOLE
+#ifndef WGP_CONSOLE
 	console = textwin.hWndParent;
-# else
+#else
 	console = GetConsoleWindow();
-# endif
+#endif
 	if (console != NULL) {
 		ShowWindow(console, SW_SHOWNORMAL);
 		BringWindowToTop(console);
